1.0.0 - 21 February 2020
==========================

Initial Release

1.1.0 - 21 Februrary 2020
===========================

Fixes import errors, Discord connections not showing and accounts for API changes

1.2.0 - 23 February 2020
==========================

Adds /topUpvoted endpoint, status code checks, better exceptions (now with messages)

1.2.0 - 13 April 2020
==========================

Finally got around to adding support for "payload" in responses, changed endpoint paths
and added support for public_flags on Discord users ("flags" property)